.. joop documentation master file, created by
   sphinx-quickstart on Mon Dec 29 17:01:14 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

joop documentation
==================

Welcome to joop
---------------

**OOP Paradigms with an emphasis on DAO patterns, HTMX, and AlpineJS.**

- Free software: Apache Software License 2.0

Features
--------

- HTML Components for server-side rendering.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules
   changelog

